# ⭐ 0.0.2 | 2024-03-20
- Add `mrms.timeseries` tools. For larger datasets, these run faster than using `xr.open_mfdataset`.


## Previous notes:

**0.0.1 | 2024-03-19**
- Initial release.
- Add `mrms.download_data` helper.